@@ -1,4 +1,7 @@
-use ark_ff::Field;
+use ark_ff::{
+    fields::{models::fp6_2over3::*, quadratic_extension::QuadExtParameters},
+    Field,
+};
 use ark_std::rand::Rng;
 use ark_std::test_rng;
 
@@ -27,20 +30,24 @@ fn test_fq() {
 }
 
 #[test]
-fn test_fq2() {
+fn test_fq3() {
     let mut rng = test_rng();
-    let a: Fq2 = rng.gen();
-    let b: Fq2 = rng.gen();
+    let a: Fq3 = rng.gen();
+    let b: Fq3 = rng.gen();
     field_test(a, b);
     sqrt_field_test(a);
-    frobenius_test::<Fq2, _>(Fq::characteristic(), 13);
+    frobenius_test::<Fq3, _>(Fq::characteristic(), 13);
+    assert_eq!(
+        a * Fq6Parameters::NONRESIDUE,
+        <Fp6ParamsWrapper<Fq6Parameters>>::mul_base_field_by_nonresidue(&a)
+    );
 }
 
 #[test]
-fn test_fq4() {
+fn test_fq6() {
     let mut rng = test_rng();
-    let a: Fq4 = rng.gen();
-    let b: Fq4 = rng.gen();
+    let a: Fq6 = rng.gen();
+    let b: Fq6 = rng.gen();
     field_test(a, b);
-    frobenius_test::<Fq4, _>(Fq::characteristic(), 13);
+    frobenius_test::<Fq6, _>(Fq::characteristic(), 13);
 }
